@@ -1,6 +1,10 @@
+use RT::Transaction ();
 package RT::Transaction;
 
 use strict;
+use warnings;
+use warnings FATAL => 'redefine';
+
 use RTx::Shredder::Constants;
 use RTx::Shredder::Exceptions;
 use RTx::Shredder::Dependencies;
